@@ -58,8 +58,8 @@ def setup_parser():
     deploy_parser.add_argument("--proxy", required=True)
     deploy_parser.add_argument("--pem", required=True)
     deploy_parser.add_argument("--arguments", nargs='+')
-    deploy_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    deploy_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    deploy_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    deploy_parser.add_argument("--gas-limit", default=config.DEFAULT_GAS_LIMIT)
     deploy_parser.add_argument("--value", default="0")
     deploy_parser.add_argument("--metadata-upgradeable", action="store_true", default=False)
     deploy_parser.set_defaults(func=deploy)
@@ -70,8 +70,8 @@ def setup_parser():
     call_parser.add_argument("--pem", required=True)
     call_parser.add_argument("--function", required=True)
     call_parser.add_argument("--arguments", nargs='+')
-    call_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    call_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    call_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    call_parser.add_argument("--gas-limit", default=config.DEFAULT_GAS_LIMIT)
     call_parser.add_argument("--value", default="0")
     call_parser.set_defaults(func=call)
 
@@ -81,8 +81,8 @@ def setup_parser():
     upgrade_parser.add_argument("--proxy", required=True)
     upgrade_parser.add_argument("--pem", required=True)
     upgrade_parser.add_argument("--arguments", nargs='+')
-    upgrade_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    upgrade_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    upgrade_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    upgrade_parser.add_argument("--gas-limit", default=config.DEFAULT_GAS_LIMIT)
     upgrade_parser.add_argument("--value", default="0")
     upgrade_parser.add_argument("--metadata-upgradeable", action="store_true", default=False)
     upgrade_parser.set_defaults(func=upgrade)
@@ -115,8 +115,8 @@ def setup_parser():
     tx_prepare_parser.add_argument("--nonce", required=True)
     tx_prepare_parser.add_argument("--value", default="0")
     tx_prepare_parser.add_argument("--receiver", required=True)
-    tx_prepare_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    tx_prepare_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    tx_prepare_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    tx_prepare_parser.add_argument("--gas-limit", default=config.DEFAULT_GAS_LIMIT)
     tx_prepare_parser.add_argument("--data", default="")
     tx_prepare_parser.add_argument("--tag", default="untitled")
     tx_prepare_parser.add_argument("workspace", nargs='?', default=os.getcwd())
@@ -131,8 +131,8 @@ def setup_parser():
     tx_prepare_and_send_parser.add_argument("--pem", required=True)
     tx_prepare_and_send_parser.add_argument("--value", default="0")
     tx_prepare_and_send_parser.add_argument("--receiver", required=True)
-    tx_prepare_and_send_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    tx_prepare_and_send_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    tx_prepare_and_send_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    tx_prepare_and_send_parser.add_argument("--gas-limit", default=config.DEFAULT_GAS_LIMIT)
     tx_prepare_and_send_parser.add_argument("--data", default="")
     tx_prepare_and_send_parser.add_argument("--proxy", required=True)
     tx_prepare_and_send_parser.set_defaults(func=tx_prepare_and_send)
@@ -144,6 +144,8 @@ def setup_parser():
     setup_parser_network(subparsers)
     setup_parser_blockatlas(subparsers)
 
+    setup_parser_queue(subparsers)
+
     return parser
 
 
@@ -169,8 +171,8 @@ def setup_parser_validators(subparsers):
     stake_prepare_parser.add_argument("--pem", required=True)
     stake_prepare_parser.add_argument("--nonce", required=True)
     stake_prepare_parser.add_argument("--value", default="0")
-    stake_prepare_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    stake_prepare_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    stake_prepare_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    stake_prepare_parser.add_argument("--gas-limit", default=config.DEFAULT_GAS_LIMIT)
     stake_prepare_parser.add_argument("--number-of-nodes", required=True)
     stake_prepare_parser.add_argument("--nodes-public-keys", required=True)
     stake_prepare_parser.add_argument("--reward-address", default="")
@@ -183,11 +185,12 @@ def setup_parser_validators(subparsers):
     stake_send_parser.add_argument("--proxy", required=True)
     stake_send_parser.set_defaults(func=stake_send)
 
-    stake_prepare_parser_and_send = subparsers.add_parser("stake-prepare-and-send")
+    stake_prepare_parser_and_send = subparsers.add_parser("stake")
     stake_prepare_parser_and_send.add_argument("--pem", required=True)
     stake_prepare_parser_and_send.add_argument("--value", default="0")
-    stake_prepare_parser_and_send.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    stake_prepare_parser_and_send.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    stake_prepare_parser_and_send.add_argument("--estimate-gas", action="store_true", default=False)
+    stake_prepare_parser_and_send.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    stake_prepare_parser_and_send.add_argument("--gas-limit", required=not("--estimate-gas" in sys.argv))
     stake_prepare_parser_and_send.add_argument("--number-of-nodes", required=True)
     stake_prepare_parser_and_send.add_argument("--nodes-public-keys", required=True)
     stake_prepare_parser_and_send.add_argument("--reward-address", default="")
@@ -197,8 +200,9 @@ def setup_parser_validators(subparsers):
     un_stake_parser = subparsers.add_parser("unstake")
     un_stake_parser.add_argument("--pem", required=True)
     un_stake_parser.add_argument("--value", default="0")
-    un_stake_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    un_stake_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    un_stake_parser.add_argument("--estimate-gas", action="store_true", default=False)
+    un_stake_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    un_stake_parser.add_argument("--gas-limit", required=not ("--estimate-gas" in sys.argv))
     un_stake_parser.add_argument("--nodes-public-keys", required=True)
     un_stake_parser.add_argument("--proxy", required=True)
     un_stake_parser.set_defaults(func=do_un_stake)
@@ -206,8 +210,9 @@ def setup_parser_validators(subparsers):
     un_jail_parser = subparsers.add_parser("unjail")
     un_jail_parser.add_argument("--pem", required=True)
     un_jail_parser.add_argument("--value", default="0")
-    un_jail_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    un_jail_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    un_jail_parser.add_argument("--estimate-gas", action="store_true", default=False)
+    un_jail_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    un_jail_parser.add_argument("--gas-limit", required=not ("--estimate-gas" in sys.argv))
     un_jail_parser.add_argument("--nodes-public-keys", required=True)
     un_jail_parser.add_argument("--proxy", required=True)
     un_jail_parser.set_defaults(func=do_un_jail)
@@ -215,8 +220,9 @@ def setup_parser_validators(subparsers):
     un_bond_parser = subparsers.add_parser("unbond")
     un_bond_parser.add_argument("--pem", required=True)
     un_bond_parser.add_argument("--value", default="0")
-    un_bond_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    un_bond_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    un_bond_parser.add_argument("--estimate-gas", action="store_true", default=False)
+    un_bond_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    un_bond_parser.add_argument("--gas-limit", required=not ("--estimate-gas" in sys.argv))
     un_bond_parser.add_argument("--nodes-public-keys", required=True)
     un_bond_parser.add_argument("--proxy", required=True)
     un_bond_parser.set_defaults(func=do_un_bond)
@@ -224,8 +230,9 @@ def setup_parser_validators(subparsers):
     change_reward_address_parser = subparsers.add_parser("change-reward-address")
     change_reward_address_parser.add_argument("--value", default="0")
     change_reward_address_parser.add_argument("--pem", required=True)
-    change_reward_address_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    change_reward_address_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    change_reward_address_parser.add_argument("--estimate-gas", action="store_true", default=False)
+    change_reward_address_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    change_reward_address_parser.add_argument("--gas-limit", required=not ("--estimate-gas" in sys.argv))
     change_reward_address_parser.add_argument("--reward-address", required=True)
     change_reward_address_parser.add_argument("--proxy", required=True)
     change_reward_address_parser.set_defaults(func=change_reward_address)
@@ -233,8 +240,9 @@ def setup_parser_validators(subparsers):
     claim_parser = subparsers.add_parser("claim")
     claim_parser.add_argument("--value", default="0")
     claim_parser.add_argument("--pem", required=True)
-    claim_parser.add_argument("--gas-price", default=config.DEFAULT_GASPRICE)
-    claim_parser.add_argument("--gas-limit", default=config.DEFAULT_GASLIMIT)
+    claim_parser.add_argument("--estimate-gas", action="store_true", default=False)
+    claim_parser.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    claim_parser.add_argument("--gas-limit", required=not ("--estimate-gas" in sys.argv))
     claim_parser.add_argument("--proxy", required=True)
     claim_parser.set_defaults(func=do_claim)
 
@@ -243,16 +251,17 @@ def setup_parser_wallet(subparsers):
     wallet_parser = subparsers.add_parser("wallet")
     wallet_subparsers = wallet_parser.add_subparsers()
 
-    generate_parser = wallet_subparsers.add_parser("generate")
-    generate_parser.add_argument("pem")
-    generate_parser.set_defaults(func=generate_pem)
+    subparser = wallet_subparsers.add_parser("generate")
+    subparser.add_argument("pem")
+    subparser.add_argument("--mnemonic", required=False, default="")
+    subparser.set_defaults(func=generate_pem)
 
-    bech32_parser = wallet_subparsers.add_parser("bech32")
-    bech32_parser.add_argument("value")
-    group = bech32_parser.add_mutually_exclusive_group(required=True)
+    subparser = wallet_subparsers.add_parser("bech32")
+    subparser.add_argument("value")
+    group = subparser.add_mutually_exclusive_group(required=True)
     group.add_argument("--encode", action="store_true")
     group.add_argument("--decode", action="store_true")
-    bech32_parser.set_defaults(func=do_bech32)
+    subparser.set_defaults(func=do_bech32)
 
 
 def setup_parser_cost(subparsers):
@@ -321,6 +330,33 @@ def setup_parser_blockatlas(subparsers):
     sub.set_defaults(func=facade.blockatlas_get_txs_by_address)
 
 
+def setup_parser_queue(subparsers):
+    parser = subparsers.add_parser("dispatcher")
+    subparsers = parser.add_subparsers()
+
+    sub = subparsers.add_parser("enqueue")
+    sub.add_argument("--value", default="0")
+    sub.add_argument("--receiver", required=True)
+    sub.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE)
+    sub.add_argument("--gas-limit", default=config.DEFAULT_GAS_LIMIT)
+    sub.add_argument("--data", default="")
+    sub.set_defaults(func=enqueue_transaction)
+
+    sub = subparsers.add_parser("dispatch")
+    sub.add_argument("--proxy", required=True)
+    sub.add_argument("--pem", required=True)
+    sub.set_defaults(func=dispatch_transactions)
+
+    sub = subparsers.add_parser("dispatch-continuously")
+    sub.add_argument("--proxy", required=True)
+    sub.add_argument("--pem", required=True)
+    sub.add_argument("--interval", required=True)
+    sub.set_defaults(func=dispatch_transactions_continuously)
+
+    sub = subparsers.add_parser("clean")
+    sub.set_defaults(func=clean_transactions_queue)
+
+
 def install(args):
     group = args.group
     dependencies.install_group(group, overwrite=True)
@@ -481,6 +517,22 @@ def do_claim(args):
     facade.prepare_and_send_claim_transaction(args)
 
 
+def enqueue_transaction(args):
+    facade.enqueue_transaction(args)
+
+
+def dispatch_transactions(args):
+    facade.dispatch_transactions(args)
+
+
+def dispatch_transactions_continuously(args):
+    facade.dispatch_transactions_continuously(args)
+
+
+def clean_transactions_queue(args):
+    facade.clean_transactions_queue()
+
+
 if __name__ == "__main__":
     try:
         main()
