@@ -25,8 +25,8 @@ class SmartContract:
 
     def prepare_deploy_transaction(self, owner, arguments, gas_price, gas_limit, value):
         arguments = arguments or []
-        gas_price = int(gas_price or config.DEFAULT_GASPRICE)
-        gas_limit = int(gas_limit or config.DEFAULT_GASLIMIT)
+        gas_price = int(gas_price or config.DEFAULT_GAS_PRICE)
+        gas_limit = int(gas_limit or config.DEFAULT_GAS_LIMIT)
         value = str(value or "0")
 
         plain = PlainTransaction()
@@ -71,8 +71,8 @@ class SmartContract:
 
     def prepare_execute_transaction(self, caller, function, arguments, gas_price, gas_limit, value):
         arguments = arguments or []
-        gas_price = int(gas_price or config.DEFAULT_GASPRICE)
-        gas_limit = int(gas_limit or config.DEFAULT_GASLIMIT)
+        gas_price = int(gas_price or config.DEFAULT_GAS_PRICE)
+        gas_limit = int(gas_limit or config.DEFAULT_GAS_LIMIT)
         value = str(value or "0")
 
         plain = PlainTransaction()
@@ -106,8 +106,8 @@ class SmartContract:
 
     def prepare_upgrade_transaction(self, owner, arguments, gas_price, gas_limit, value):
         arguments = arguments or []
-        gas_price = int(gas_price or config.DEFAULT_GASPRICE)
-        gas_limit = int(gas_limit or config.DEFAULT_GASLIMIT)
+        gas_price = int(gas_price or config.DEFAULT_GAS_PRICE)
+        gas_limit = int(gas_limit or config.DEFAULT_GAS_LIMIT)
         value = str(value or "0")
 
         plain = PlainTransaction()
