@@ -57,6 +57,11 @@ class ProxyRequestError(KnownError):
         super().__init__(f"Proxy request error for url [{url}]: {data}")
 
 
+class BlockAtlasRequestError(KnownError):
+    def __init__(self, url, data):
+        super().__init__(f"Block Atlas request error for url [{url}]: {data}")
+
+
 class BadInputError(KnownError):
     def __init__(self, input, message):
         super().__init__(f"Bad input [{input}]: {message}")
