@@ -4,6 +4,7 @@ from erdpy import wallet
 from erdpy.accounts import Account, Address
 from erdpy.blockatlas import BlockAtlas
 from erdpy.contracts import CodeMetadata, SmartContract
+from erdpy.dispatcher.transactions.queue import TransactionQueue
 from erdpy.environments import TestnetEnvironment
 from erdpy.projects import load_project
 from erdpy.proxy import ElrondProxy, TransactionCostEstimator
@@ -259,13 +260,37 @@ def prepare_and_send_claim_transaction(args):
     return prepare_and_send_transaction(args)
 
 
+def enqueue_transaction(args):
+    queue = TransactionQueue()
+    queue.enqueue_transaction(args)
+
+
+def dispatch_transactions(args):
+    queue = TransactionQueue()
+    queue.dispatch_transactions(args)
+
+
+def dispatch_transactions_continuously(args):
+    queue = TransactionQueue()
+    queue.dispatch_transactions_continuously(args)
+
+
+def clean_transactions_queue():
+    queue = TransactionQueue()
+    queue.clean_transactions_queue()
+
+
 def generate_pem(args):
     pem_file = args.pem
+    mnemonic = args.mnemonic
 
     seed, pubkey = wallet.generate_pair()
+    if mnemonic:
+        seed, pubkey = wallet.derive_keys(mnemonic)
+
     address = Address(pubkey)
     pem.write(pem_file, seed, pubkey, name=address.bech32())
-    logger.info(f"Created PEM file [{pem_file}].")
+    logger.info(f"Created PEM file [{pem_file}] for [{address.bech32()}]")
 
 
 def do_bech32(args):
