@@ -14,7 +14,7 @@ class ProjectCpp(Project):
 
     def perform_build(self):
         self.build_configuration = CppBuildConfiguration(self, self.debug)
-        self.unit = self.find_file("*.cpp")
+        self.unit = self.find_file_globally("*.cpp")
         self.file_ll = self.unit.with_suffix(".ll")
         self.file_o = self.unit.with_suffix(".o")
         self.file_export = self.unit.with_suffix(".export")
@@ -64,7 +64,7 @@ class ProjectCpp(Project):
             tool,
             "--no-entry",
             str(self.file_o),
-            "-o", self.get_file_wasm(),
+            "-o", self.find_file_globally("*.cpp").with_suffix(".wasm"),
             "--strip-all",
             f"--allow-undefined",
             "--demangle"
@@ -78,8 +78,9 @@ class ProjectCpp(Project):
 
         myprocess.run_process(args)
 
-    def get_file_wasm(self):
-        return self.find_file("*.cpp").with_suffix(".wasm")
+    def _copy_build_artifacts_to_output(self):
+        wasm_file = self.find_file_globally("*.cpp").with_suffix(".wasm")
+        self._copy_to_output(wasm_file)
 
     def _get_llvm_path(self):
         return dependencies.get_install_directory("llvm")
@@ -95,6 +96,6 @@ class CppBuildConfiguration:
         self.exports = self._get_exports()
 
     def _get_exports(self):
-        file_export = self.project.find_file("*.export")
+        file_export = self.project.find_file_globally("*.export")
         lines = utils.read_lines(file_export)
         return lines
