@@ -1,8 +1,7 @@
-import os
 import shutil
 from os import path
 
-from erdpy import config, downloader, workstation, errors, utils
+from erdpy import downloader, errors, utils, workstation
 from erdpy.projects import shared
 
 
@@ -17,7 +16,10 @@ class TemplatesRepository:
         archive = self._get_archive_path()
         downloader.download(self.url, archive)
         templates_folder = self.get_folder()
-        shutil.rmtree(templates_folder)
+        try:
+            shutil.rmtree(templates_folder)
+        except FileNotFoundError:
+            pass
         utils.unzip(archive, templates_folder)
 
     def _get_archive_path(self):
@@ -59,4 +61,4 @@ class TemplatesRepository:
             return "Solidity"
         if shared.is_source_rust(directory):
             return "Rust"
-        return "unknown"
\ No newline at end of file
+        return "unknown"
